#!/usr/bin/python -tt
# ********************************
# Test script for the CalFits class
# 
# written by Thomas Kraehenbuehl, ETH Zurich
# tpk@phys.ethz.ch, +41 44 633 3973
# April 2012
# ********************************
#
# modified and adapted py Patrick Vogler
#
# ################################
from ROOT import gSystem
gSystem.Load("calfactfits_h.so")   # according to new naming scheme
from ROOT import *

# from ROOT import  TCanvas, TH1F


c1 = TCanvas( 'c1', 'Example', 200, 10, 700, 500 )
hpx = TH1F( 'hpx', 'px', 500,-50, 450 )



#define filenames

# 2012 04 17
#calibfilename = '/fact/raw/2012/04/17/20120417_003.drs.fits.gz'    # NROI 300, pedestal
#calibfilename = '/fact/raw/2012/04/17/20120417_033.drs.fits.gz'    # NROI 300, pedestal
calibfilename = '/fact/raw/2012/06/01/20120601_013.drs.fits.gz'    # NROI 300, pedestal

#datafilename = '/fact/raw/2012/04/17/20120417_015.fits.gz'         # NROI 300, LP_ext
#datafilename = '/fact/raw/2012/04/17/20120417_021.fits.gz'         # NROI 300, LP_ext
#datafilename = '/fact/raw/2012/04/17/20120417_036.fits.gz'         # NROI 300, LP_ext
#datafilename = '/fact/raw/2012/04/17/20120417_042.fits.gz'         # NROI 300, LP_ext

datafilename = '/fact/raw/2012/06/01/20120601_017.fits.gz'          # NROI 300, 5 minutes physics data with
                                                                    # interleaved LP_ext

import numpy as np
from scipy import weave
from scipy.weave import converters

from plotters import Plotter         # ADC display
from plotters import CamPlotter      # event display
#from drs_spikes import DRSSpikes


print "Testing object creation: "
caltest = CalFactFits(datafilename, calibfilename)
npcalevent  = np.empty( caltest.npix * caltest.nroi, np.float64) #.reshape(caltest.npix ,caltest.nroi)
caltest.SetNpcaldataPtr(npcalevent)


numroi = np.int64(caltest.nroi)
numpix = np.int64(caltest.npix)
numevents = np.int64(caltest.nevents)

num_LP_ev = 0   # number of ext Lightpulser events
num_ped = 0     # number of pedestal events


print "Common variables run information: "
print "ROI: ", numroi
print "#Pix: ", numpix
print "Number of events: ", numevents
print


event = np.zeros((numpix, numroi))  # create an array to store an event in the format numpix * numroi (2-dim array)
print "Array event created"
run_average = np.zeros((numpix, numroi))   # create an array to store the "average event" of a run
print "Array run_average created"
extracted_average = np.zeros(numpix)
print "Array extracted_average created "
data_average_run = np.zeros(numroi)
print "Arrays created "




print "... looping..."

while caltest.GetCalEvent():    # Loop  ueber alle events
    # print npcalevent  ## Daten, Array   1 dim Laenge caltest.npix * caltest.nroi   1 Event


    if ((caltest.event_triggertype > 256) and (caltest.event_triggertype < 512)):  #ext LP event

        print 'event id:', caltest.event_id, '  Trigger Type:', caltest.event_triggertype

        num_LP_ev = num_LP_ev + 1

        event = np.reshape(npcalevent, (numpix, -1))     # bring the event the shape numpix * numroi (2-dim array)

        run_average += event

        # A first test of Adrians idea of primitive signal extractor
        # signal and background
        extracted_signal = np.zeros(numpix)
        for signalslice in range(90, 100):
            extracted_signal += event[0:(numpix), signalslice]
        # background subtraction
        for backgroundslice in range(15, 25):
            extracted_signal -= event[0:(numpix), backgroundslice]
        extracted_average += extracted_signal



print "Looped ... "

for i in range (0, (numpix - 1) ):
    data_average_run += run_average[i]


print "Looped second loop "


del caltest
print "caltest deleted "



print "Common variables run information: "
print "ROI: ", numroi
print "#Pix: ", numpix
print "Number of events: ", numevents
print "Number of external Lightpulser events: ", num_LP_ev
print




for k in range (0, (numpix) ):
   px = gRandom.Gaus()
   hpx.Fill((extracted_average[k] / (10 * num_LP_ev)) )

hpx.Draw()
c1.Update()


#####################################################################################################################
print "creating plotters ..."

#make a Plotter class ... this is an easy way for plotting ... but there are 
# many was to plot data ... without this class ... it was written for convenience, but there is no strong reason to use it...
#myplotter = Plotter('titel of the plot', xlabel='time in slices', ylabel='amplitude calibrated data ... in mV')

myplotter2 = Plotter('titel of the plot', xlabel='time in slices', ylabel='amplitude calibrated data ... in mV')

# make a CamPlotter class
mycamplotter2 = CamPlotter('titel of the plot',  map_file_path = 'map_dn.txt', vmin=0, vmax=400)    # for pedestal data

print "Plotters created "
###################################################################################################################


#myplotter((run_average[22]) / numevents, 'pix 22, average' )

myplotter2( data_average_run / (numpix * num_LP_ev) , 'average signal (all pixel) over the whole run' )


#mycamplotter( data[0:1443, 100] )    # plot slice 100 of all pixel


mycamplotter2( extracted_average / (10 * num_LP_ev) )  # plot the extracted pedestal of all pixel



answer = raw_input('type "quit" to quit ')
while not 'quit' in answer:
     answer = raw_input('type "quit" to quit ')
